@@ -17,7 +17,7 @@ cat(paste("--------- Executing",
 #
 # Tests for lpp code
 #
-#  $Revision: 1.69 $  $Date: 2021/03/19 03:13:19 $
+#  $Revision: 1.72 $  $Date: 2024/06/05 09:11:58 $
 
 
 local({
@@ -52,13 +52,13 @@ local({
 
     #' check 'normalise' option in linearKinhom
     fit <- lppm(Xsimple ~x)
-    K <- linearKinhom(Xsimple, lambda=fit, normalise=FALSE)
+    K <- linearKinhom(Xsimple, lambda=fit, normalise=FALSE, leaveoneout=FALSE)
     plot(K)
-    g <- linearpcfinhom(Xsimple, lambda=fit, normalise=FALSE)
+    g <- linearpcfinhom(Xsimple, lambda=fit, normalise=FALSE, leaveoneout=FALSE)
     plot(g)
-    K <- linearKinhom(Xsimple, lambda=fit, normalise=TRUE)
+    K <- linearKinhom(Xsimple, lambda=fit, normalise=TRUE, leaveoneout=FALSE)
     plot(K)
-    g <- linearpcfinhom(Xsimple, lambda=fit, normalise=TRUE)
+    g <- linearpcfinhom(Xsimple, lambda=fit, normalise=TRUE, leaveoneout=FALSE)
     plot(g)
     ## other code blocks
     K <- linearKinhom(Xsimple, lambda=fit, correction="none", ratio=TRUE)
@@ -195,7 +195,12 @@ local({
     X0 <- insertVertices(X, x=numeric(0), y=numeric(0))
     ## vertices on boundary of new window
     LL <- simplenet[boundingbox(vertices(simplenet))]
-  
+
+    ## thinNetwork for lpp and linim
+    Xthin <- thinNetwork(X, retainedges=1:3)
+    D <- density(X, 0.1)
+    Dthin <- thinNetwork(D, retainedges=1:3)
+    
     ## Test [.lpp internal data
     B <- owin(c(0.1,0.7),c(0.19,0.6))
     XB <- X[B]
@@ -279,6 +284,13 @@ local({
     xcoord <- as.linim(xcoord, dimyx=32)
     integral(xcoord)
 
+    ## Math.linim
+    range(xcoord)
+    stopifnot(is.linim(sqrt(xcoord)))
+    stopifnot(is.linim(-xcoord))
+    stopifnot(is.linim(xcoord + xcoord))
+    stopifnot(is.linim(xcoord/3))
+
     ## options to plot.linim
     plot(xcoord, legend=FALSE)
     plot(xcoord, leg.side="top")
@@ -756,20 +768,20 @@ local({
   }
 
   #' fundamental utilities:
-  #' evalCovar
+  #' spatialCovariateEvidence (was: evalCovar)
   ycoord <- function(x,y) { y }
   if(ALWAYS) YS <- as.linim(ycoord, L=domain(spiders))
   if(FULLTEST) YC <- as.linim(ycoord, L=domain(chicago))
 
-  if(ALWAYS) aT <- evalCovar(fit1, YS, interpolate=TRUE)
+  if(ALWAYS) aT <- spatialCovariateEvidence(fit1, YS, interpolate=TRUE)
   if(FULLTEST) {
-    aF <- evalCovar(fit1, YS, interpolate=FALSE)
-    dT <- evalCovar(fit1, ycoord, interpolate=TRUE)
-    dF <- evalCovar(fit1, ycoord, interpolate=FALSE)
-    bT <- evalCovar(fit2, YC, interpolate=TRUE)
-    bF <- evalCovar(fit2, YC, interpolate=FALSE)
-    cT <- evalCovar(fit2, ycoord, interpolate=TRUE)
-    cF <- evalCovar(fit2, ycoord, interpolate=FALSE)
+    aF <- spatialCovariateEvidence(fit1, YS, interpolate=FALSE)
+    dT <- spatialCovariateEvidence(fit1, ycoord, interpolate=TRUE)
+    dF <- spatialCovariateEvidence(fit1, ycoord, interpolate=FALSE)
+    bT <- spatialCovariateEvidence(fit2, YC, interpolate=TRUE)
+    bF <- spatialCovariateEvidence(fit2, YC, interpolate=FALSE)
+    cT <- spatialCovariateEvidence(fit2, ycoord, interpolate=TRUE)
+    cF <- spatialCovariateEvidence(fit2, ycoord, interpolate=FALSE)
   }
   
 })
